@@ -153,6 +153,12 @@ public class LdapContactStorage extends DefaultContactStorage {
         return doList(session, folderId, ids, fields, sortOptions);
     }
 
+    @Override
+    public int count(Session session, String folderId, boolean canReadAll) throws OXException {
+        check(session.getContextId(), folderId);
+        return count(session, config.getBaseDN(), config.getSearchfilter());
+    }
+
     @Override
     public SearchIterator<Contact> deleted(Session session, String folderId, Date since, ContactField[] fields, SortOptions sortOptions) throws OXException {
         check(session.getContextId(), folderId);
@@ -193,7 +199,7 @@ public class LdapContactStorage extends DefaultContactStorage {
     }
 
     @Override
-    public void updateReferences(Session session, Contact contact) throws OXException {
+    public void updateReferences(Session session, Contact originalContact, Contact updatedContact) throws OXException {
         // Nothing to do
     }
 
@@ -308,6 +314,19 @@ public class LdapContactStorage extends DefaultContactStorage {
         }
     }
 
+    protected int count(Session session, String baseDN, String filter) throws OXException {
+        LdapExecutor executor = null;
+        try {
+            executor = new LdapExecutor(factory, session);
+            List<LdapResult> results = executor.search(baseDN, filter, new String[0], null, getMaxResults(SortOptions.EMPTY));
+            return results.size();
+        } finally {
+            if (null != executor) {
+                executor.close();
+            }
+        }
+    }
+
     private List<Contact> search(Session session, ContactField[] fields, LdapMapper mapper, String baseDN, String filter,
         SortKey[] sortKeys, int maxResults, boolean deleted) throws OXException {
         LdapIDResolver idResolver = getIDResolver(session);
